<?php


namespace OCA\GrueneGroupfolderManagement\Cache;

use OCP\ICache;

class DefaultTtlDecorator implements ICache {
	public const FALLBACK_TTL = 60;

	/**
	 * @var ICache
	 */
	protected $cache;

	/**
	 * @var int
	 */
	protected $ttl = self::FALLBACK_TTL;

	public function __construct(ICache $cache, int $ttl = self::FALLBACK_TTL) {
		$this->cache = $cache;
		$this->ttl = $ttl;
	}

	public function get($key) {
		return $this->cache->get($key);
	}

	public function set($key, $value, $ttl = 0) {
		if ($ttl === 0 || $ttl === null) {
			$ttl = $this->ttl;
		}

		return $this->cache->set($key, $value, $ttl);
	}

	public function hasKey($key) {
		return $this->cache->hasKey($key);
	}

	public function remove($key) {
		return $this->cache->remove($key);
	}

	public function clear($prefix = '') {
		return $this->cache->remove($prefix);
	}

	
	public static function isAvailable(): bool {
		return true;
	}
}
