<?php


namespace OCA\GrueneGroupfolderManagement\Cache;

use OCP\ICache;

class PrefixDecorator implements ICache {
	/**
	 * @var ICache
	 */
	protected $cache;

	/**
	 * @var string
	 */
	protected $prefix;

	public function __construct(ICache $cache, string $prefix = '') {
		$this->cache = $cache;
		$this->prefix = $prefix;
	}

	protected function prefix($key) : string {
		return $this->prefix . $key;
	}

	public function get($key) {
		return $this->cache->get($this->prefix($key));
	}

	public function set($key, $value, $ttl = 0) {
		return $this->cache->set($this->prefix($key), $value, $ttl);
	}

	public function hasKey($key) {
		return $this->cache->hasKey($this->prefix($key));
	}

	public function remove($key) {
		return $this->cache->remove($this->prefix($key));
	}

	public function clear($prefix = '') {
		return $this->cache->remove($this->prefix($prefix));
	}
	
	public static function isAvailable(): bool {
		return true;
	}
}
