<?php

namespace OCA\GrueneGroupfolderManagement\Controller;

use OCA\GrueneGroupfolderManagement\Constants\Constants;
use OCA\GrueneGroupfolderManagement\Db\GroupMapper;
use OCA\GrueneGroupfolderManagement\Manager\DivisionManager;
use OCA\GrueneGroupfolderManagement\Manager\GroupFolderManager;
use OCA\GrueneGroupfolderManagement\Groups\GroupName;
use OCP\AppFramework\Http\JSONResponse;
use OCP\IGroupManager;
use OCP\IUserSession;
use Psr\Log\LoggerInterface;

class FolderController extends BaseController {

	public function __construct(
		private IUserSession $userSession,
		private IGroupManager $groupManager,
		private DivisionManager $divisionManager,
		private GroupFolderManager $groupFolderManager,
		private GroupMapper $groupMapper,
		private LoggerInterface $logger,
	) {
		parent::__construct();
	}

	/**
	 * @NoAdminRequired
	 */
	public function current() {
		$user = $this->userSession->getUser();
		$currentPath = $this->request->getParams()['currentPath'];
		$path = explode('/', trim($currentPath, '/'));
		$groupFolder = $this->groupFolderManager->getGroupFolderByMountPoint($path[0]);

		if (!$groupFolder) {
			return new JsonResponse(['isGroupFolder' => false]);
		}

		$userGroups = $this->groupManager->getUserGroupIds($user);
		$groupFolderDirectory = $this->groupFolderManager->getGroupFolder($groupFolder['folder_id']);
		$groupFolderSize = $groupFolderDirectory->getSize();
		$division = $this->divisionManager->find($groupFolder['organization_key']);

		if ($division === null) {
			$this->logger->error(
				sprintf(
					'api.netzbegruenung/v1/party/regionalchapters/ request not successful for mountpoint [%s] with org_key [%s] despite it was found in db',
					$groupFolder['mount_point'],
					$groupFolder['organization_key']
				),
				['app' => 'gruenegroupfoldermanagement']
			);
			return new JsonResponse([
				'bannerActive' => false,
				'isGroupFolder' => true,
				'isRoot' => count($path) === 1,
				'isExecutiveBoard' => false,
				'used' => $groupFolderSize,
				'quota' => (int)$groupFolder['quota']
			]);
		}
		// check user for technical editor role
		$isTechEditor = in_array(GroupName::getTechnicalEditorGroupName($division), $userGroups);
		$isGroupAdmin = false;
		$group = null;
		if (count($path) > 1) {
			// check if user is admin for this group
			try {
				$grueneFolderId = $groupFolderDirectory->get($path[1])->getId();
				$group = $this->groupMapper->getGroupByFolderId($groupFolder['organization_key'], $grueneFolderId);
				$adminPattern = sprintf("/^GROUP_%d_%d_ADMINS$/", $division->getId(), $group->getId());
				$isGroupAdmin = !empty(preg_grep($adminPattern, $userGroups));
			} catch (\Throwable $e) {
				if (!in_array($path[1], Constants::DEFAULT_DIRECTORIES)) {
					// default directories cannot be configured via banner and therefore cannot have admins
					// default directories can only be accessed by managers and executive board
					$this->logger->error(
						sprintf('Could not check admin access for folder [%s] in [%s] with org_key [%s], group not found', $path[1], $path[0], $groupFolder['organization_key']),
						['app' => 'gruenegroupfoldermanagement']
					);
				}
			}
		}
		$bannerActive = $isTechEditor || $isGroupAdmin;
		// check user for sherpa manager role
		$pattern = sprintf("/^SHERPA_%d_[A-Z]+_EXECUTIVE_BOARD$/", $division->getId());
		$matches = preg_grep($pattern, $userGroups);

		$groupId = false;
		if (!is_null($group)) {
			$groupId = $group->getId();
		}

		return new JsonResponse([
			'bannerActive' => $bannerActive && $path !== '#',
			'isGroupFolder' => true,
			'isRoot' => count($path) === 1,
			'divisionKey' => $division->getId(),
			'groupId' => $groupId,
			'isExecutiveBoard' => !empty($matches),
			'used' => $groupFolderSize,
			'quota' => (int)$groupFolder['quota']
		]);
	}
}
