<?php

namespace OCA\GrueneGroupfolderManagement\Controller;

use OCA\GrueneGroupfolderManagement\Groups\GroupName;
use OCA\GrueneGroupfolderManagement\Manager\DivisionManager;
use OCA\GrueneGroupfolderManagement\Manager\SherpaManager;
use OCP\AppFramework\Http\JSONResponse;

class SherpaController extends BaseController {
	public function __construct(
		private DivisionManager $divisionManager,
		private SherpaManager $sherpaManager,
	) {
		parent::__construct();
	}

	/**
	 * @NoAdminRequired
	 */
	public function findDivisions(string $org, string $type = null, string $search = null) {
        if (!in_array($org, ['GR', 'GJ', 'KPV'])) {
            $this->createValidationException("invalid organization: {$org}");
        }
        if ($type && !in_array($type, ['BV', 'LV', 'OV', 'LV'])) {
            $this->createValidationException("invalid type: {$type}");
        }

		$prefix = [
			'GR' => '1',
			'GJ' => '2',
			'KPV' => '3',
		];

        $divisions = $this->divisionManager->findAll(
            $search,
            $prefix[$org],
            $type,
		);

		return new JsonResponse([
			'items' => $divisions,
		]);
	}

	/**
	 * @NoAdminRequired
	 */
	public function findGroups(string $division) {
        $division = $this->divisionManager->find($division);

		$groups = [];
		if ($division) {
			$groups = iterator_to_array($this->sherpaManager->findByDivision($division));
		}

        return new JSONResponse([
            'items' => $groups,
        ]);

	}

	/**
	 * @NoAdminRequired
	 */
	public function subdivisions(string $parent = null) {
		$prefix = $parent;

		if(is_null($prefix) || $prefix == '') {
			return new JSONResponse([
				'subdivisions' => [
					[ 'type'=> 'division', 'prefix'=> '1', 'friendlyName'=> 'BÜNDNIS 90/DIE GRÜNEN' ],
					[ 'type'=> 'division', 'prefix'=> '2', 'friendlyName'=> 'GRÜNE JUGEND' ],
					[ 'type'=> 'division', 'prefix'=> '3', 'friendlyName'=> 'Kommunalpolitische Vereinigung' ]
				],
			]);
		} else {
			// limit to next smaller division type
			$type = "";
			if(substr($prefix, 0, 1) == "3") {
				// KPV
				$type = "BV";
			} else {
				// BV and LV
				if (strlen($prefix) == 1) {
					$type = "LV";
				} else if (strlen($prefix) == 3) {
					$type = "KV";
				} else if (strlen($prefix) == 6) {
					$type = "OV";
				}
			}

			$division = $this->divisionManager->find($prefix);

			$subdivisions = [];

			// division members
			if ($division) {
				$subdivisions[] = ['type'=> 'group', 'name'=> GroupName::divisionMember($division), 'friendlyName'=> "Mitglieder" ];
			}
			
			// subdivisions
			$divisionEntities = $this->divisionManager->findAll(
				null,
				$prefix,
				type: $type
			);

			foreach($divisionEntities as $entity) {
				// the division itself is not a subdivision
				if($entity->getId() != $prefix) {
					$subdivisions[] = [ 'type'=> 'division', 'prefix'=> $entity->getPrefix(), 'name'=> $entity->getName(), 'friendlyName'=> $entity->getType() . " " . $entity->getName() , 'divisionType'=> $entity->getType(), ];
				}
			}

			// groups
			if ($division) {
				$groupEntities = $this->sherpaManager->findByDivision($division);

				foreach($groupEntities as $entity) {
					$subdivisions[] = ['type'=> 'group', 'name'=> GroupName::sherpa($entity), 'friendlyName'=> $entity->getGroup()->getName() ];
				}
			}
			

			return new JSONResponse([
				'subdivisions' => $subdivisions,
			]);
		}
	}
}
