<?php

namespace OCA\GrueneGroupfolderManagement\Manager;

use OCP\IDBConnection;

class MappingManager {
	/**
	 * @var IDBConnection
	 */
	protected $db;

	public function __construct(
		IDBConnection $db
	) {
		$this->db = $db;
	}


	/**
	 * Fetch the folder id for this division group
	 *
	 * @param string $divisionId
	 * @param string $index
	 * @return string|false
	 */
	public function fetchForeignKey(string $divisionId, string $index) {
		$qb = $this->db->getQueryBuilder();
		$qb->select('foreign_key')
			->from('gruenegfm_mapping')
			->where($qb->expr()->eq('division_key', $qb->createNamedParameter($divisionId)))
			->andWhere($qb->expr()->eq('index', $qb->createNamedParameter($index)));
		$stmt = $qb->execute();
		$result = $stmt->fetchOne();
		return $result;
	}


	/**
	 * Set folder id for this division group
	 *
	 * @param string $foreignKey
	 * @param string $divisionId
	 * @param string $index
	 * @return void
	 */
	public function setForeignKey(string $foreignKey, string $divisionId, string $index) {
		$qb = $this->db->getQueryBuilder();
		$hasFolder = $this->fetchForeignKey($divisionId, $index);
		if (!$hasFolder) {
			$qb->insert('gruenegfm_mapping')
				->setValue('index', $qb->createNamedParameter($index))
				->setValue('division_key', $qb->createNamedParameter($divisionId))
				->setValue('foreign_type', $qb->createNamedParameter('folder'))
				->setValue('foreign_key', $qb->createNamedParameter($foreignKey));
		} else {
			$qb->update('gruenegfm_mapping')
				->set('foreign_key', $qb->createNamedParameter($foreignKey))
				->where($qb->expr()->eq('division_key', $qb->createNamedParameter($divisionId)))
				->andWhere($qb->expr()->eq('index', $qb->createNamedParameter($index)))
				->andWhere($qb->expr()->eq('foreign_type', $qb->createNamedParameter('folder')));
		}
		$qb->execute();
	}


	/**
	 * Deletes all mappings for the passed folder id
	 *
	 * @param int $folderId
	 * @return void
	 */
	public function deleteFolder($folderId) {
		$query = $this->db->getQueryBuilder();
		$query->delete('gruenegfm_mapping')
			->where($query->expr()->eq('foreign_key', $query->createNamedParameter($folderId)));
		$query->execute();
	}
}
