<?php

namespace OCA\GrueneGroupfolderManagement\Middleware;

use OCA\GrueneGroupfolderManagement\Exceptions\AccessDeniedException;
use OCA\GrueneGroupfolderManagement\Exceptions\ConflictedStateException;
use OCP\AppFramework\Middleware;
use OCA\GrueneGroupfolderManagement\Exceptions\NotFoundException;
use OCA\GrueneGroupfolderManagement\Exceptions\ValidationFailedException;
use OCP\AppFramework\Http;
use OCP\AppFramework\Http\JSONResponse;

class ErrorMiddleware extends Middleware {
	public function afterException($controller, $methodName, \Exception $exception) {
		$data = ['message' => $exception->getMessage()];
		if ($exception instanceof NotFoundException) {
			return new JSONResponse($data, Http::STATUS_NOT_FOUND);
		}
		if ($exception instanceof ValidationFailedException) {
			$data['violations'] = $exception->getViolations();
			return new JSONResponse($data, Http::STATUS_BAD_REQUEST);
		}
		if ($exception instanceof AccessDeniedException) {
			return new JSONResponse($data, Http::STATUS_FORBIDDEN);
		}
		if ($exception instanceof ConflictedStateException) {
			return new JSONResponse($data, Http::STATUS_CONFLICT);
		}
		return new JSONResponse($data, Http::STATUS_INTERNAL_SERVER_ERROR);
	}
}
