<?php

namespace OCA\GrueneGroupfolderManagement\Model\Api;

class Group implements \JsonSerializable {
	/**
	 * @var string
	 */
	protected $name;

	/**
	 * @var string
	 */
	protected $type;

	/**
	 * @var string
	 */
	protected $slug;

	/**
	 * @var bool
	 */
	protected $active;

	/**
	 * @var string
	 */
	protected $level;

	/**
	 * @var array
	 */
	protected $externalRefs;

	/**
	 * @return string
	 */
	public function getName(): ?string {
		return $this->name;
	}

	/**
	 * @param string $name
	 */
	public function setName(?string $name): void {
		$this->name = $name;
	}

	/**
	 * @return string
	 */
	public function getSlug(): ?string {
		return $this->slug;
	}

	/**
	 * @param string $slug
	 */
	public function setSlug(?string $slug): void {
		$this->slug = $slug;
	}

	/**
	 * @return string
	 */
	public function getType(): string {
		return $this->type;
	}

	/**
	 * @param string $type
	 */
	public function setType(string $type): void {
		$this->type = $type;
	}

	/**
	 * @return bool
	 */
	public function isActive(): bool {
		return $this->active;
	}

	/**
	 * @param bool $active
	 */
	public function setActive(bool $active): void {
		$this->active = $active;
	}

	/**
	 * @return string
	 */
	public function getLevel(): string {
		return $this->level;
	}

	/**
	 * @param string $level
	 */
	public function setLevel(string $level): void {
		$this->level = $level;
	}

	/**
	 * @return array
	 */
	public function getExternalRefs(): array {
		return $this->externalRefs;
	}

	/**
	 * @param array $externalRefs
	 */
	public function setExternalRefs(array $externalRefs): void {
		$this->externalRefs = $externalRefs;
	}

	/**
	 * @return string[]
	 */
	public function getSherpaIds() : array {
		$ids = [];
		foreach ($this->externalRefs as $externalRef) {
			if ($externalRef['type'] == 'SHERPA') {
				$ids[] = $externalRef['key'];
			}
		}
		return $ids;
	}

	/**
	 * Specify data which should be serialized to JSON
	 * @link https://php.net/manual/en/jsonserializable.jsonserialize.php
	 * @return mixed data which can be serialized by <b>json_encode</b>,
	 * which is a value of any type other than a resource.
	 * @since 5.4.0
	 */
	public function jsonSerialize(): mixed {
		return [
			'name' => $this->getName() === null ? $this->getSlug() : $this->getName(),
			'type' => $this->getType(),
			'slug' => $this->getSlug(),
			'level' => $this->getLevel(),
			'active' => $this->isActive()
		];
	}
}
