<?php

namespace OCA\GrueneGroupfolderManagement\Model;

use OCA\GrueneGroupfolderManagement\Groups\GroupName;

class Division implements OrganizationalUnitInterface, \JsonSerializable {
	/**
	 * @var string
	 */
	protected $id;

	/**
	 * @var string
	 */
	protected $typ;

	/**
	 * @var string
	 */
	protected $name;

	/**
	 * @var null|Organization
	 */
	protected $organization;

	public function getOrganizationalUuid() {
		return $this->getId();
	}

	public function getOrganizationalQuery() {
		return [
			'organization_key' => $this->getId(),
			'organization_subdivison_name' => null
		];
	}

	public function getOrganizationalName() {
		if ($this->getOrganization()->getId() == 'GR') {
			return $this->getShortKey() . '_' . $this->getName();
		} else {
			$orga = $this->getOrganization()->getName();
			if ($this->getLevel() == 'DE:BUNDESVERBAND') {
				return $this->getShortKey() . '_' . $orga;
			} else {
				return $this->getShortKey() . '_' . $orga . ' - ' . $this->getName();
			}
		}
	}

	/**
	 * @return string
	 */
	public function getId() {
		return $this->id;
	}

	/**
	 * @param string $id
	 */
	public function setId($id) {
		$this->id = $id;
	}

	public function getPrefix() {
		switch ($this->getType()) {
			case 'LV':
				return substr($this->getId(), 0, 3);
			case 'KV':
				return substr($this->getId(), 0, 6);
			case 'OV':
				return substr($this->getId(), 0, 8);
		}

		return $this->getId();
	}

	public function getShortKey() {
		switch ($this->getType()) {
			case 'LV':
				return substr($this->getId(), 0, 3);
			case 'KV':
				return substr($this->getId(), 0, 6);
			case 'OV':
				return substr($this->getId(), 0, 8);
		}

		return rtrim($this->getId(), '0');
	}

	/**
	 * @return null|Organization
	 */
	public function getOrganization(): ?Organization {
		return $this->organization;
	}

	/**
	 * @param null|Organization $organization
	 */
	public function setOrganization(?Organization $organization): void {
		$this->organization = $organization;
	}

	/**
	 * @return string
	 * @deprecated
	 */
	public function getTyp() {
		return $this->getType();
	}

	/**
	 * @param string $typ
	 * @deprecated
	 */
	public function setTyp($typ) {
		$this->setType($typ);
	}

	/**
	 * @return string|null
	 */
	public function getType() {
		return $this->typ;
	}

	/**
	 * @param string|null $type
	 */
	public function setType($type) {
		$this->typ = $type;
	}

	public function getLevel() : string {
		switch ($this->getType()) {
			case 'LV':
				return 'DE:LANDESVERBAND';
			case 'KV':
				return 'DE:KREISVERBAND';
			case 'OV':
				return 'DE:ORTSVERBAND';
		}

		return 'DE:BUNDESVERBAND';
	}

	/**
	 * @return string
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * @param string $name
	 */
	public function setName($name) {
		$this->name = $name;
	}

	/**
	 * Specify data which should be serialized to JSON
	 * @link https://php.net/manual/en/jsonserializable.jsonserialize.php
	 * @return mixed data which can be serialized by <b>json_encode</b>,
	 * which is a value of any type other than a resource.
	 * @since 5.4.0
	 */
	public function jsonSerialize(): mixed {
		return [
			'id' => $this->getId(),
			'group' => GroupName::divisionMember($this),
			'prefix' => $this->getPrefix(),
			'name' => $this->getName(),
			'level' => $this->getLevel(),
			'type' => $this->getType(),
			'organization' => $this->getOrganization()
		];
	}
}
