<?php

namespace OCA\GrueneGroupfolderManagement\Settings;

use OCP\AppFramework\Http\TemplateResponse;
use OCP\BackgroundJob\IJobList;
use OCP\IConfig;
use OCP\IDateTimeFormatter;
use OCP\IL10N;
use OCP\Settings\ISettings;

class Admin implements ISettings {
	public const DEFAULT_GROUP_FILTER = '^SAML_([0-9]+)';

	public const DEFAULT_ROLE_FILTER = '^SAML_[0-9]+_([0-9]+)';

	public const DEFAULT_QUOTA = 5368709120;

	public const DEFAULT_API_SERVER = 'https://api.netzbegruenung.de/';

	/** @var IConfig */
	private $config;

	/** @var IL10N */
	private $l;

	/** @var IDateTimeFormatter */
	private $dateTimeFormatter;

	/** @var IJobList */
	private $jobList;

	/**
	 * Admin constructor.
	 *
	 * @param IConfig $config
	 * @param IL10N $l
	 * @param IDateTimeFormatter $dateTimeFormatter
	 * @param IJobList $jobList
	 */
	public function __construct(IConfig $config,
								IL10N $l,
								IDateTimeFormatter $dateTimeFormatter,
								IJobList $jobList
	) {
		$this->config = $config;
		$this->l = $l;
		$this->dateTimeFormatter = $dateTimeFormatter;
		$this->jobList = $jobList;
	}

	public function getForm() {
		$groupFilterPattern = $this->config->getAppValue('gruenegroupfoldermanagement', 'group_filter_pattern', Admin::DEFAULT_GROUP_FILTER);

		$roleFilterPattern = $this->config->getAppValue('gruenegroupfoldermanagement', 'role_filter_pattern', Admin::DEFAULT_ROLE_FILTER);

		$defaultQuota = $this->config->getAppValue('gruenegroupfoldermanagement', 'default_quota', Admin::DEFAULT_QUOTA);

		$shareUser = $this->config->getAppValue('gruenegroupfoldermanagement', 'share_user');

		$shareGroup = $this->config->getAppValue('gruenegroupfoldermanagement', 'share_group');

		$apiServer = $this->config->getAppValue('gruenegroupfoldermanagement', 'api_server', Admin::DEFAULT_API_SERVER);

		$apiUser = $this->config->getAppValue('gruenegroupfoldermanagement', 'api_user');

		$apiPassword = $this->config->getAppValue('gruenegroupfoldermanagement', 'api_password');

		$parameters = [
			'group_filter_pattern' => $groupFilterPattern,
			'role_filter_pattern' => $roleFilterPattern,
			'default_quota' => $defaultQuota,
			'share_user' => $shareUser,
			'share_group' => $shareGroup,
			'api_server' => $apiServer,
			'api_user' => $apiUser,
			'api_password' => $apiPassword
		];

		return new TemplateResponse('gruenegroupfoldermanagement', 'settings/admin', $parameters);
	}

	public function getSection() {
		return 'gruenegroupfoldermanagement';
	}

	public function getPriority() {
		return 50;
	}
}
